@@ -4,7 +4,7 @@
 #
 #     This program is under GPL [http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt]
 #
-#     (c) 2000,2001,2002,2003,2004,2005,2006,2007 - Tom Eastep (teastep@shorewall.net)
+#     (c) 2000,2001,2002,2003,2004,2005,2006,2007,2008,2009,2010 - Tom Eastep (teastep@shorewall.net)
 #
 #       Shorewall documentation is available at http://shorewall.net
 #
@@ -22,7 +22,7 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=4.2.10
+VERSION=4.4.6
 
 usage() # $1 = exit status
 {
@@ -30,7 +30,6 @@ usage() # $1 = exit status
     echo "usage: $ME"
     echo "       $ME -v"
     echo "       $ME -h"
-    echo "       $ME -n"
     exit $1
 }
 
@@ -76,41 +75,6 @@ cant_autostart()
     echo  "WARNING: Unable to configure shorewall6-lite to start automatically at boot" >&2
 }
 
-backup_directory() # $1 = directory to backup
-{
-    if [ -d $1 ]; then
-	if cp -a $1  ${1}-${VERSION}.bkout ; then
-	    echo
-	    echo "$1 saved to ${1}-${VERSION}.bkout"
-	else
-	    exit 1
-	fi
-    fi
-}
-
-backup_file() # $1 = file to backup, $2 = (optional) Directory in which to create the backup
-{
-    if [ -z "${PREFIX}${NOBACKUP}" ]; then
-	if [ -f $1 -a ! -f ${1}-${VERSION}.bkout ]; then
-	    if [ -n "$2" ]; then
-		if [ -d $2 ]; then
-		    if cp -f $1 $2 ; then
-			echo
-			echo "$1 saved to $2/$(basename $1)"
-		    else
-			exit 1
-		    fi
-		fi
-	    elif cp $1 ${1}-${VERSION}.bkout; then
-		echo
-		echo "$1 saved to ${1}-${VERSION}.bkout"
-	    else
-		exit 1
-	    fi
-	fi
-    fi
-}
-
 delete_file() # $1 = file to delete
 {
     rm -f $1
@@ -121,12 +85,6 @@ install_file() # $1 = source $2 = target $3 = mode
     run_install $OWNERSHIP -m $3 $1 ${2}
 }
 
-install_file_with_backup() # $1 = source $2 = target $3 = mode $4 = (optional) backup directory
-{
-    backup_file $2 $4
-    run_install $OWNERSHIP -m $3 $1 ${2}
-}
-
 #
 # Parse the run line
 #
@@ -149,16 +107,6 @@ if [ -z "$RUNLEVELS" ] ; then
 	RUNLEVELS=""
 fi
 
-if [ -z "$OWNER" ] ; then
-	OWNER=root
-fi
-
-if [ -z "$GROUP" ] ; then
-	GROUP=root
-fi
-
-NOBACKUP=
-
 while [ $# -gt 0 ] ; do
     case "$1" in
 	-h|help|?)
@@ -168,9 +116,6 @@ while [ $# -gt 0 ] ; do
 	    echo "Shorewall6 Lite Firewall Installer Version $VERSION"
 	    exit 0
 	    ;;
-	-n)
-	    NOBACKUP=Yes
-	    ;;
 	*)
 	    usage 1
 	    ;;
@@ -186,16 +131,32 @@ PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/bin:/usr/local/sbin
 #
 DEBIAN=
 
+case $(uname) in
+    CYGWIN*)
+	if [ -z "$PREFIX" ]; then
+	    DEST=
+	    INIT=
+	fi
+
+	OWNER=$(id -un)
+	GROUP=$(id -gn)
+	;;
+    *)
+	[ -z "$OWNER" ] && OWNER=root
+	[ -z "$GROUP" ] && GROUP=root
+	;;
+esac
+
 OWNERSHIP="-o $OWNER -g $GROUP"
 
 if [ -n "$PREFIX" ]; then
-	if [ `id -u` != 0 ] ; then
-	    echo "Not setting file owner/group permissions, not running as root."
-	    OWNERSHIP=""
-	fi
-
-	install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
-	install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
+    if [ `id -u` != 0 ] ; then
+	echo "Not setting file owner/group permissions, not running as root."
+	OWNERSHIP=""
+    fi
+    
+    install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
+    install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
 elif [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
     DEBIAN=yes
 elif [ -f /etc/slackware-version ] ; then
@@ -214,20 +175,11 @@ cd "$(dirname $0)"
 
 echo "Installing Shorewall6 Lite Version $VERSION"
 
-#
-# First do Backups
-#
-
 #
 # Check for /etc/shorewall6-lite
 #
 if [ -z "$PREFIX" -a -d /etc/shorewall6-lite ]; then
     first_install=""
-    if [ -z "$NOBACKUP" ]; then
-	backup_directory /etc/shorewall6-lite
-	backup_directory /usr/share/shorewall6-lite
-	backup_directory /var/lib/shorewall6-lite
-    fi
     [ -f /etc/shorewall6-lite/shorewall.conf ] && \
 	mv -f /etc/shorewall6-lite/shorewall.conf /etc/shorewall6-lite/shorewall6-lite.conf
 else
@@ -239,7 +191,7 @@ fi
 
 delete_file ${PREFIX}/usr/share/shorewall6-lite/xmodules
 
-install_file_with_backup shorewall6-lite ${PREFIX}/sbin/shorewall6-lite 0544 ${PREFIX}/var/lib/shorewall6-lite-${VERSION}.bkout
+install_file shorewall6-lite ${PREFIX}/sbin/shorewall6-lite 0544 ${PREFIX}/var/lib/shorewall6-lite-${VERSION}.bkout
 
 echo "Shorewall6 Lite control program installed in ${PREFIX}/sbin/shorewall6-lite"
 
@@ -247,12 +199,12 @@ echo "Shorewall6 Lite control program installed in ${PREFIX}/sbin/shorewall6-lit
 # Install the Firewall Script
 #
 if [ -n "$DEBIAN" ]; then
-    install_file_with_backup init.debian.sh /etc/init.d/shorewall6-lite 0544 ${PREFIX}/usr/share/shorewall6-lite-${VERSION}.bkout
+    install_file init.debian.sh /etc/init.d/shorewall6-lite 0544 ${PREFIX}/usr/share/shorewall6-lite-${VERSION}.bkout
 elif [ -n "$ARCHLINUX" ]; then
-    install_file_with_backup init.archlinux.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-lite-${VERSION}.bkout
+    install_file init.archlinux.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-lite-${VERSION}.bkout
 
 else
-    install_file_with_backup init.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-lite-${VERSION}.bkout
+    install_file init.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall6-lite-${VERSION}.bkout
 fi
 
 echo  "Shorewall6 Lite script installed in ${PREFIX}${DEST}/$INIT"
@@ -267,6 +219,11 @@ mkdir -p ${PREFIX}/var/lib/shorewall6-lite
 chmod 755 ${PREFIX}/etc/shorewall6-lite
 chmod 755 ${PREFIX}/usr/share/shorewall6-lite
 
+if [ -n "$PREFIX" ]; then
+    mkdir -p ${PREFIX}/etc/logrotate.d
+    chmod 755 ${PREFIX}/etc/logrotate.d
+fi
+
 #
 # Install the config file
 #
@@ -351,6 +308,11 @@ cd ..
 
 echo "Man Pages Installed"
 
+if [ -d ${PREFIX}/etc/logrotate.d ]; then
+    run_install $OWNERSHIP -m 0644 logrotate ${PREFIX}/etc/logrotate.d/shorewall6-lite
+    echo "Logrotate file installed as ${PREFIX}/etc/logrotate.d/shorewall6-lite"
+fi
+
 #
 # Create the version file
 #
